% Michael Vodhanel
% 5/01/05

% Purpose:	Draw the statistical analysis of the data ser covariances with the
%				ICA and POd modes

% Input:
%	POD_Cor:		The corelations of the data with one of the POD modes
%	ICA_Cor:		The corelations of the data with one of the ICA modes
%	NumOfTumor:	The number of samples known to contain cancer in the data set
%	MinCor:		The minimum covariance found with any of the modes
%	MaxCor:		The maximum covariance found with any of the modes

% Output:
%	Normal Covariance Distributions of the normal and tumorous samples
%	with both POD and ICA to the screen.
%	Histograms of the normal and tumorous samples with both POD and ICA
%	to the screen.
%	Percentage of cancer plots for both POD and ICA to the screen

function PlotNormalAnalysis(POD_Cor, ICA_Cor, NumOfTumor, MinCor, MaxCor, FigNum)

NumOfSamples = length(POD_Cor);

% Get the means and standard deviations for the normal and tumorous samples
% covariances with the POD mode
POD_Normal_Cov_Mean = mean(POD_Cor([NumOfTumor+1:NumOfSamples]));
POD_Normal_Cov_STD = std(POD_Cor([NumOfTumor+1:NumOfSamples]));
POD_Tumor_Cov_Mean = mean(POD_Cor([1:NumOfTumor]));
POD_Tumor_Cov_STD = std(POD_Cor([1:NumOfTumor]));

% Get the means and standard deviations for the normal and tumorous samples
% covariances with the ICA mode
ICA_Normal_Cov_Mean = mean(ICA_Cor([NumOfTumor+1:NumOfSamples]));
ICA_Normal_Cov_STD = std(ICA_Cor([NumOfTumor+1:NumOfSamples]));
ICA_Tumor_Cov_Mean = mean(ICA_Cor([1:NumOfTumor]));
ICA_Tumor_Cov_STD = std(ICA_Cor([1:NumOfTumor]));

% Prepare to draw the plots
figure(FigNum); clf

% Draw the normal distribution of the covariances of thenormal and tumorous sets
% with the POD mode
xlin = [MinCor:0.01:MaxCor];
POD_Normal_Dist = Normal_pdf(xlin, POD_Normal_Cov_Mean, POD_Normal_Cov_STD);
POD_Tumor_Dist = Normal_pdf(xlin, POD_Tumor_Cov_Mean, POD_Tumor_Cov_STD);
ICA_Normal_Dist = Normal_pdf(xlin, ICA_Normal_Cov_Mean, ICA_Normal_Cov_STD);
ICA_Tumor_Dist = Normal_pdf(xlin, ICA_Tumor_Cov_Mean, ICA_Tumor_Cov_STD);
TempMax=max([POD_Normal_Dist POD_Tumor_Dist ICA_Normal_Dist ICA_Tumor_Dist]);

subplot(2, 4, 1)
hold on;
plot(xlin, POD_Normal_Dist, 'b','linewidth',2)
plot(xlin, POD_Tumor_Dist, 'r','linewidth',2)
title('First POD Mode Covariance Distributions')
legend('Normal', 'Tumor')
axis([MinCor, MaxCor, 0, 1.1*TempMax])
hold off;

% Draw the normal distribution of the covariances of thenormal and tumorous sets
% with the ICA mode
subplot(2, 4, 5)
hold on;
plot(xlin, ICA_Normal_Dist, 'b','linewidth',2)
plot(xlin, ICA_Tumor_Dist, 'r','linewidth',2)
title('First ICA Mode Covariance Distributions')
legend('Normal', 'Tumor')
axis([MinCor, MaxCor, 0, 1.1*TempMax])
hold off;

% Draw the histogram of the normal data sets covariances with the POD mode
subplot(2, 4, 2)
[n, xout] = hist(POD_Cor([NumOfTumor+1:NumOfSamples]), [MinCor:5:MaxCor]);
bar(xout, n)
axis([MinCor-5 MaxCor+5 0 max(n)]) 
title('POD - Normal Histogram')

% Draw the histogram of the tumorous data sets covariances with the POD mode
subplot(2, 4, 3)
[n, xout] = hist(POD_Cor([1:NumOfTumor]), [MinCor:5:MaxCor]);
bar(xout, n)
axis([MinCor-5 MaxCor+5 0 max(n)]) 
set(findobj(gca,'Type','patch'),'FaceColor','r')
title('POD - Tumor Histogram')

% Draw the histogram of the normal data sets covariances with the ICA mode
subplot(2, 4, 6)
[n, xout] = hist(ICA_Cor([NumOfTumor+1:NumOfSamples]), [MinCor:5:MaxCor]);
bar(xout, n)
axis([MinCor-5 MaxCor+5 0 max(n)]) 
title('ICA - Normal Histogram')

% Draw the histogram of the normal data sets covariances with the ICA mode
subplot(2, 4, 7)
[n, xout] = hist(ICA_Cor([1:NumOfTumor]), [MinCor:5:MaxCor]);
bar(xout, n)
axis([MinCor-5 MaxCor+5 0 max(n)])
set(findobj(gca,'Type','patch'),'FaceColor','r')
title('ICA - Tumor Histogram')

% Draw the percentage of cancer plot for the POD test
subplot(2, 4, 4)
Curve = POD_Tumor_Dist ./ ( POD_Tumor_Dist + POD_Normal_Dist );
TempInd1=find(diff(Curve)<0);
TempInd2=find(xlin<0);
TempInd=intersect(TempInd1,TempInd2);
plot(xlin(max(TempInd):length(Curve)), Curve(max(TempInd):length(Curve)), 'b','linewidth',2)
axis([MinCor, MaxCor, 0, 1.1])
title('POD - Percent Tumor')

% Draw the percentage of cancer plot for the ICA test
subplot(2, 4, 8)
Curve = ICA_Tumor_Dist ./ ( ICA_Tumor_Dist + ICA_Normal_Dist );
plot(xlin, Curve, 'b','linewidth',2)
axis([MinCor, MaxCor, 0, 1.1])
title('ICA - Percent Tumor')